@@ -3,6 +3,7 @@ import string
 from inspect import isclass
 
 from Crypto.Cipher import AES
+from django.contrib.auth import get_user_model
 from django.conf import settings
 from django.core.exceptions import FieldError, ImproperlyConfigured
 from django.db import models
@@ -308,11 +309,16 @@ class SearchField(models.CharField):
         # Eg str(datetime(10, 9, 2020))
         value = str(value)
 
+        if callable(self.hash_key):
+            hash_key = self.hash_key()
+        else:
+            hash_key = self.hash_key
+
         if is_hashed_already(value):
             # if we have hashed this previously, don't do it again
             return value
 
-        v = value + self.hash_key
+        v = value + hash_key
         return SEARCH_HASH_PREFIX + hashlib.sha256(v.encode()).hexdigest()
 
     def formfield(self, **kwargs):
@@ -361,6 +367,10 @@ class SearchField(models.CharField):
 
         SearchField's 'max_length' constraint will still be enforced at the database
         level, but applied to the saved hash value."""
+        if model_instance is None:
+            # This will happen when calling manage.py createuser/createsuperuser
+            model_instance = get_user_model()
+
         return model_instance._meta.get_field(self.encrypted_field_name).clean(
             value, model_instance
         )
